
Metpack CLI Commands
--------------------

**mp**: Main program
====================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :maxdepth: 1

**config**: Show Configuration Information
==========================================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: config

**doc**: Display package documentation
======================================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: doc

**index**: Add a package to the search index
============================================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: index

**info**: Show Package information
==================================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: info

**open**: Open a resource as a CSV file
=======================================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: open

**run**: Run a resource to produce data
=======================================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: run

**search**: Search for a package
================================

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: search

